@@ -11,8 +11,10 @@ from os import path
 from http.server import BaseHTTPRequestHandler, HTTPServer
 from minecraft_launcher_lib import microsoft_account as msa
 from minecraft_launcher_lib.microsoft_types import CompleteLoginResponse
+from ice_launcher import dirs
 
 
+__accounts_file__: str = path.join(dirs.user_data_dir, "accounts.json")
 __client_id__: str = "0018ddff-bd2f-4cc6-b220-66f6a4462a5c"
 __redirect_uri__: str = "http://localhost:3003"
 
@@ -31,17 +33,17 @@ def new_document() -> Document:
 
 
 def read_document() -> Document:
-    if not path.exists("accounts.json"):
+    if not path.exists(__accounts_file__):
         doc = new_document()
 
-    with open("accounts.json", "r") as f:
-        doc: Document = json.load(f)
+    with open(__accounts_file__, "r") as f:
+        doc = json.load(f)
 
     return doc
 
 
 def write_document(doc: Document) -> None:
-    with open("accounts.json", "w") as f:
+    with open(__accounts_file__, "w") as f:
         json.dump(doc, f)
 
 
@@ -50,14 +52,14 @@ class CallbackHandler(BaseHTTPRequestHandler):
     code_verifier: str
 
     def do_GET(self) -> None:
-        auth_code = msa.get_auth_code_from_url(self.path)
-        assert auth_code is not None
+        auth_code = msa.parse_auth_code_url(self.path, self.state)
 
         login_data = msa.complete_login(
             client_id=__client_id__,
             client_secret=None,
             redirect_uri=__redirect_uri__,
             auth_code=auth_code,
+            code_verifier=self.code_verifier
         )
 
         doc = read_document()
@@ -113,10 +115,12 @@ class Accounts(CTkFrame):
         self.update_accounts_list()
 
     def add_account(self) -> None:
-        login_url = msa.get_login_url(__client_id__, __redirect_uri__)
+        login_url, state, code_verifier = msa.get_secure_login_data(__client_id__, __redirect_uri__)
 
         webbrowser.open(login_url)
         handler = CallbackHandler
+        handler.state = state
+        handler.code_verifier = code_verifier
         httpd = HTTPServer(("127.0.0.1", 3003), handler)
         httpd.serve_forever()
         self.update_accounts_list()
